Ufun.1eSC <- function(x, gamval, omeval)
{
   #  This evaluates the 4 functions spanning the kernel of the operator
   #  L = (gamval D + D^2) * (omval^2 I + D^2)
   #  at the array X of argument values
   
   #  There are four cases, associated with a set of spanning functions:
   #  gamval   and omeval nonzero:  1, exp(gamval*x), sin(omval*x), cos(omval*x) 
   #  gamval 0 and omeval nonzero:  1, x            , sin(omval*x), cos(omval*x) 
   #  gamval nonzero and omeval 0:  1, x, x^2, exp(gamval*x), 
   #  gamval and omeval 0:          1, x, x^2, x^3
   
   #  The last case is not handled; instead a message indicates that one 
   #  should use the module Pspline
   
   #  Returns a length(x) by 4 array of kernel function values

   if (gamval == 0 & omeval == 0) 
     stop ("Both GAMVAL and OMEVAL 0, use Pspline module instead.")
     
   if (abs(gamval) > 20) 
     stop ("Value of GAMVAL exceeds 20")
     
   n     <- length(x)
   u     <- matrix(0,n,4)

   if (gamval == 0) {
     u[,1] <- 1
     u[,2] <- x
     u[,3] <- sin(omeval*x)
     u[,4] <- cos(omeval*x)
   }
   
   if (omeval == 0) {
     u[,1] <- 1
     u[,2] <- x
     u[,3] <- x^2
     u[,4] <- exp(gamval*x)
   }

   if (gamval != 0 & omeval != 0) {
     u[,1] <- 1
     u[,2] <- exp(gamval*x)
     u[,3] <- sin(omeval*x)
     u[,4] <- cos(omeval*x)
   }

   return(u)
}

Ufun.1E <- function(x, gamval) 
{
   #  compute the kernel functions 1, exp(gamval*x) for L = -gamval D + D^2

   #  Returns a length(x) by 2 array of kernel function values
   
   if (gamval == 0)  
     stop ("GAMVAL = 0, use Pspline module instead.")
     
   if (abs(gamval) > 20) 
     stop ("Value of GAMVAL exceeds 20")

   n      <- length(x)
   u      <- matrix(0,n,2)
   u[,1]  <- 1
   u[,2]  <- exp(gamval*x)
   return(u)
}

Ufun.1tE <- function(x, gamval) 
{
   #  compute the kernel functions 1, exp(gamval*x) for L = -gamval D^2 + D^3

   #  Returns a length(x) by 3 array of kernel function values
   
   if (gamval == 0)  
     stop ("GAMVAL = 0, use Pspline module instead.")
     
   if (abs(gamval) > 20) 
     stop ("Value of GAMVAL exceeds 20")

   n      <- length(x)
   u      <- matrix(0,n,2)
   u[,1]  <- 1
   u[,2]  <- x
   u[,3]  <- exp(gamval*x)
   return(u)
}

Ufun.1tt2E <- function(x, gamval) 
{
   #  compute the kernel functions 1, exp(gamval*x) for L = -gamval D^3 + D^4

   #  Returns a length(x) by 4 array of kernel function values
   
   if (gamval == 0)  
     stop ("GAMVAL = 0, use Pspline module instead.")
     
   if (abs(gamval) > 20) 
     stop ("Value of GAMVAL exceeds 20")

   n      <- length(x)
   u      <- matrix(0,n,2)
   u[,1]  <- 1
   u[,2]  <- x
   u[,3]  <- x^2
   u[,4]  <- exp(gamval*x)
   return(u)
}
